@@ -10,6 +10,7 @@ use Perl6::Pod::Block::para;
 use Perl6::Pod::Block::table;
 use Perl6::Pod::Block::output;
 use Perl6::Pod::Block::input;
+use Perl6::Pod::Parser::NOTES;
 use Perl6::Pod::FormattingCode::C;
 use Perl6::Pod::FormattingCode::M;
 use Perl6::Pod::FormattingCode::L;
@@ -18,6 +19,7 @@ use Perl6::Pod::FormattingCode::B;
 use Perl6::Pod::FormattingCode::I;
 use Perl6::Pod::FormattingCode::X;
 use Perl6::Pod::FormattingCode::E;
+use Perl6::Pod::FormattingCode::N;
 
 use Tie::UnionHash;
 use Data::Dumper;
@@ -43,6 +45,7 @@ use constant {
         table   => 'Perl6::Pod::Block::table',
         output  => 'Perl6::Pod::Block::output',
         input   => 'Perl6::Pod::Block::input',
+        '_NOTES_'   => 'Perl6::Pod::Parser::NOTES',
         'C<>'   => 'Perl6::Pod::FormattingCode::C',
         'M<>'   => 'Perl6::Pod::FormattingCode::M',
         'L<>'   => 'Perl6::Pod::FormattingCode::L',
@@ -52,6 +55,7 @@ use constant {
 
         #        'P<>'   => 'Perl6::Pod::FormattingCode::P',
         'E<>' => 'Perl6::Pod::FormattingCode::E',
+        'N<>' => 'Perl6::Pod::FormattingCode::N',
     }
 };
 
